HilbertMCA
==========

.. currentmodule:: xeofs.cross

.. autoclass:: HilbertMCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HilbertMCA.__init__
      ~HilbertMCA.components
      ~HilbertMCA.components_amplitude
      ~HilbertMCA.components_phase
      ~HilbertMCA.compute
      ~HilbertMCA.correlation_coefficients_X
      ~HilbertMCA.correlation_coefficients_Y
      ~HilbertMCA.covariance_fraction_CD95
      ~HilbertMCA.cross_correlation_coefficients
      ~HilbertMCA.deserialize
      ~HilbertMCA.fit
      ~HilbertMCA.fraction_variance_X_explained_by_X
      ~HilbertMCA.fraction_variance_Y_explained_by_X
      ~HilbertMCA.fraction_variance_Y_explained_by_Y
      ~HilbertMCA.get_params
      ~HilbertMCA.get_serialization_attrs
      ~HilbertMCA.heterogeneous_patterns
      ~HilbertMCA.homogeneous_patterns
      ~HilbertMCA.inverse_transform
      ~HilbertMCA.load
      ~HilbertMCA.predict
      ~HilbertMCA.save
      ~HilbertMCA.scores
      ~HilbertMCA.scores_amplitude
      ~HilbertMCA.scores_phase
      ~HilbertMCA.serialize
      ~HilbertMCA.squared_covariance_fraction
      ~HilbertMCA.transform
   
   

   
   
   